# Top-level functions

## Array/Chunked Array functions

::: geoarrow.rust.core
    options:
      filters:
        - "!^_"
      members:
        - affine_transform
        - area
        - center
        - centroid
        - chaikin_smoothing
        - convex_hull
        - densify
        - envelope
        - frechet_distance
        - geodesic_perimeter
        - is_empty
        - length
        - line_interpolate_point
        - line_locate_point
        - polylabel
        - signed_area
        - simplify
        - total_bounds

## Table functions

::: geoarrow.rust.core
    options:
      filters:
        - "!^_"
      members:
        - explode
